@@ -91,7 +91,7 @@ class Tokens:
     @staticmethod
     def __embed_token_semantics(token:Token) -> ndarray:
         embedding = zeros(SIZE_SEMANTIC_VECTOR,dtype=int)
-        if token.id > SIZE_SEMANTIC_VECTOR:
+        if token.id >= SIZE_SEMANTIC_VECTOR:
             return embedding
         embedding[token.id] = 1
         for name in token.semantics:
